@@ -3,12 +3,10 @@ use std::net::SocketAddr;
 use std::time::Duration;
 
 use slings::net::UdpSocket;
-use slings::runtime::Runtime;
 use slings::time::delay_for;
 
 fn main() -> io::Result<()> {
-    let runtime = Runtime::new()?;
-    runtime.block_on(async {
+    slings::block_on(async {
         let socket = UdpSocket::bind("127.0.0.1:0").unwrap();
         println!("local addr: {}", socket.local_addr().unwrap());
         let buf = b"helloworld";
